#[alert]Expand description
Creates an Alert struct that implements Display and From for multiple error types.
Usage:
#[alert(errors = [MyError, AnotherError])]
pub struct Alert {
message: String,
}#[alert]Creates an Alert struct that implements Display and From for multiple error types.
Usage:
#[alert(errors = [MyError, AnotherError])]
pub struct Alert {
message: String,
}